summaryrefslogtreecommitdiff
path: root/include/leveldb/options.h
diff options
context:
space:
mode:
authorcostan <costan@google.com>2018-04-10 16:18:06 -0700
committerVictor Costan <pwnall@chromium.org>2018-04-10 16:26:43 -0700
commit09217fd0677a4fd9713c7a4d774c494a7d3c1f15 (patch)
tree7b22f6275e16b1cb5059aa726d59e8c5a357c1d5 /include/leveldb/options.h
parent6a3b915166fce75aaf9ac209114a3ad9caa34171 (diff)
downloadleveldb-09217fd0677a4fd9713c7a4d774c494a7d3c1f15.tar.gz
Replace NULL with nullptr in C++ files.
------------- Created by MOE: https://github.com/google/moe MOE_MIGRATED_REVID=192365747
Diffstat (limited to 'include/leveldb/options.h')
-rw-r--r--include/leveldb/options.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/include/leveldb/options.h b/include/leveldb/options.h
index 1c42921..b6ddbd8 100644
--- a/include/leveldb/options.h
+++ b/include/leveldb/options.h
@@ -63,9 +63,9 @@ struct LEVELDB_EXPORT Options {
Env* env;
// Any internal progress/error information generated by the db will
// be written to info_log if it is non-NULL, or to a file stored
// in the same directory as the DB contents if info_log is NULL.
// Default: NULL
Logger* info_log;
// -------------------
@@ -93,9 +93,9 @@ struct LEVELDB_EXPORT Options {
// Control over blocks (user data is stored in a set of blocks, and
// a block is the unit of reading from disk).
// If non-NULL, use the specified cache for blocks.
// If NULL, leveldb will automatically create and use an 8MB internal cache.
// Default: NULL
Cache* block_cache;
// Approximate size of user data packed per block. Note that the
@@ -147,11 +147,11 @@ struct LEVELDB_EXPORT Options {
// Default: currently false, but may become true later.
bool reuse_logs;
- // If non-NULL, use the specified filter policy to reduce disk reads.
+ // If non-null, use the specified filter policy to reduce disk reads.
// Many applications will benefit from passing the result of
// NewBloomFilterPolicy() here.
//
- // Default: NULL
+ // Default: nullptr
const FilterPolicy* filter_policy;
// Create an Options object with default values for all fields.
@@ -170,17 +170,17 @@ struct LEVELDB_EXPORT ReadOptions {
// Default: true
bool fill_cache;
- // If "snapshot" is non-NULL, read as of the supplied snapshot
+ // If "snapshot" is non-null, read as of the supplied snapshot
// (which must belong to the DB that is being read and which must
- // not have been released). If "snapshot" is NULL, use an implicit
+ // not have been released). If "snapshot" is null, use an implicit
// snapshot of the state at the beginning of this read operation.
- // Default: NULL
+ // Default: nullptr
const Snapshot* snapshot;
ReadOptions()
: verify_checksums(false),
fill_cache(true),
- snapshot(NULL) {
+ snapshot(nullptr) {
}
};
@@ -63,9 +63,9 @@ struct LEVELDB_EXPORT Options {
Env* env;
// Any internal progress/error information generated by the db will
- // be written to info_log if it is non-NULL, or to a file stored
- // in the same directory as the DB contents if info_log is NULL.
- // Default: NULL
+ // be written to info_log if it is non-null, or to a file stored
+ // in the same directory as the DB contents if info_log is null.
+ // Default: nullptr
Logger* info_log;
// -------------------
@@ -93,9 +93,9 @@ struct LEVELDB_EXPORT Options {
// Control over blocks (user data is stored in a set of blocks, and
// a block is the unit of reading from disk).
- // If non-NULL, use the specified cache for blocks.
- // If NULL, leveldb will automatically create and use an 8MB internal cache.
- // Default: NULL
+ // If non-null, use the specified cache for blocks.
+ // If null, leveldb will automatically create and use an 8MB internal cache.
+ // Default: nullptr
Cache* block_cache;
// Approximate size of user data packed per block. Note that the